rhyzophora: Allometry in mangrove trees
Description
Canopy to height ratio and variables of root area in mangrove trees sampled in two soil types.
Format
A data frame with 24 rows (trees) and 4 variables:
- soil.instability
- soil type according to instability; factor with two levels (high / medium)
- canopy.trunk
- ratio between canopy and trunk area, both in m2, numeric
- root
- area covered by aerial roots, numeric (m2)
- n.roots
- number of aerial roots, integer
Prado, A. et al. 2013. Variações na morfologia de sustentação em Rhizophora mangle (Rizophoraceae) em diferentes
condições de inundação do solo. Curso de campo "Ecologia da Mata Atlântica"
(G. Machado, P.I. Prado & A.M.Z. Martini eds.). Universidade de São Paulo, São Paulo.
http://ecologia.ib.usp.br/curso/2013/pdf/PO4-2.pdfDetails
Data from a field practical exercise to test if mangrove trees in more unstable soil
allocates more biomass in supporting roots.